The core library for the polybox crate.
See GitHub for more information.
Re-exports
pub use type_sets;
Modules
Structs
- Boxed
Payload - Holds a
MessageSpecifier::Payload - DynInbox
- A dynamic inbox that can accept messages of any type, as long as they are part of the specified set.
- Fire
AndForget - A marker type for fire-and-forget messages.
- Request
- A marker type for request messages.
Traits
- DynPoly
Box - Object-safe sub-trait of
PolyBox, allowing for dynamic dispatch. - From
Payload - Interface
- An interface defines the set of messages that can be sent to a given actor.
This is usually derived on an enum using the
#[derive(Interface)]macro. - Message
- A trait that must be implemented for all types that are sent as messages.
- Message
Ext - A trait that extends
Messagewith some helper methods. - Message
Reply - A trait for types that can be used as the output of a
Message. - Message
Specifier - A trait for types that can be used to specify the kind of a
Message. - PolyBox
- A trait that allows for conversions to
DynInbox. - Polybox
Ext - A trait that extends
PolyBoxwith some helper methods. - Sends
- Implemented for inboxes that can send messages of type
T. - Sends
Ext - Extension trait for
Sends. - TryInto
Payload
Type Aliases
- Output
- A helper type for the output of a
Message. - Payload
- A helper type for the payload of a
Message. - Reply
- A helper type for the reply of a
Message.