Module errors

Module errors 

Structs

SendError
The channel has been closed, and no longer accepts new messages.

Enums

RequestError
Error returned when sending a request.
SendCheckedError
Error returned when sending a message, checking at compile-time that the message is actually accepted by the actor.