Module oneshot

Module oneshot 

Structs

Rx
The receiver part of a request, created with new_request.
RxError
Error returned when receiving a message using an Rx.
Tx
The transmitter part of a request, created with new_request.
TxError
Error returned when sending a message using a Tx.

Enums

TryRxError
Error returned when trying to receive a message using an Rx.

Functions

new_request
Create a new request, consisting of a Tx<T> and an Rx<T>. The Tx (transmitter) can be used to send a single message T to the Rx (receiver).