pub struct DynInbox<T> { /* private fields */ }Expand description
A dynamic inbox that can accept messages of any type, as long as they are part of the specified set.
An inbox is typed as: DynInbox<Set![Msg1, Msg2, ...]>.
Conversions between inboxes:
- Into more specific subsets ->
PolyboxExt::into_dyn_subset. - Into more general supersets ->
PolyboxExt::into_dyn_checkedorPolyBox::into_dyn_unchecked.
Implementations
Sourceimpl<T> DynInbox<T>
impl<T> DynInbox<T>
pub fn new_unchecked(inbox: Arc<dyn DynPolyBox>) -> Self
pub fn new<R>(inbox: R) -> Self