Message

Trait Message 

pub trait Message:
    Send
    + 'static
    + Sized {
    type Kind: MessageSpecifier<Self>;
}
A trait that must be implemented for all types that are sent as messages.

It defines the kind of the message, which can be either Request<T> or FireAndForget.

Required Associated Types

type Kind: MessageSpecifier<Self>

The kind of the message, which can be either Request<T> or FireAndForget.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Message for &'static str

Source

impl Message for ()

Source

impl Message for String

Source

impl Message for i8

Source

impl Message for i16

Source

impl Message for i32

Source

impl Message for i64

Source

impl Message for i128

Source

impl Message for u8

Source

impl Message for u16

Source

impl Message for u32

Source

impl Message for u64

Source

impl Message for u128

Source

impl<M1, M2, M3, M4, M5, M6, M7, M8, M9, M10> Message for (M1, M2, M3, M4, M5, M6, M7, M8, M9, M10)
where M1: Message + Send + 'static, M2: Message + Send + 'static, M3: Message + Send + 'static, M4: Message + Send + 'static, M5: Message + Send + 'static, M6: Message + Send + 'static, M7: Message + Send + 'static, M8: Message + Send + 'static, M9: Message + Send + 'static, M10: Message + Send + 'static,

Source

impl<M1, M2, M3, M4, M5, M6, M7, M8, M9> Message for (M1, M2, M3, M4, M5, M6, M7, M8, M9)
where M1: Message + Send + 'static, M2: Message + Send + 'static, M3: Message + Send + 'static, M4: Message + Send + 'static, M5: Message + Send + 'static, M6: Message + Send + 'static, M7: Message + Send + 'static, M8: Message + Send + 'static, M9: Message + Send + 'static,

Source

impl<M1, M2, M3, M4, M5, M6, M7, M8> Message for (M1, M2, M3, M4, M5, M6, M7, M8)
where M1: Message + Send + 'static, M2: Message + Send + 'static, M3: Message + Send + 'static, M4: Message + Send + 'static, M5: Message + Send + 'static, M6: Message + Send + 'static, M7: Message + Send + 'static, M8: Message + Send + 'static,

Source

impl<M1, M2, M3, M4, M5, M6, M7> Message for (M1, M2, M3, M4, M5, M6, M7)
where M1: Message + Send + 'static, M2: Message + Send + 'static, M3: Message + Send + 'static, M4: Message + Send + 'static, M5: Message + Send + 'static, M6: Message + Send + 'static, M7: Message + Send + 'static,

Source

impl<M1, M2, M3, M4, M5, M6> Message for (M1, M2, M3, M4, M5, M6)
where M1: Message + Send + 'static, M2: Message + Send + 'static, M3: Message + Send + 'static, M4: Message + Send + 'static, M5: Message + Send + 'static, M6: Message + Send + 'static,

Source

impl<M1, M2, M3, M4, M5> Message for (M1, M2, M3, M4, M5)
where M1: Message + Send + 'static, M2: Message + Send + 'static, M3: Message + Send + 'static, M4: Message + Send + 'static, M5: Message + Send + 'static,

Source

impl<M1, M2, M3, M4> Message for (M1, M2, M3, M4)
where M1: Message + Send + 'static, M2: Message + Send + 'static, M3: Message + Send + 'static, M4: Message + Send + 'static,

Source

impl<M1, M2, M3> Message for (M1, M2, M3)
where M1: Message + Send + 'static, M2: Message + Send + 'static, M3: Message + Send + 'static,

Source

impl<M1, M2> Message for (M1, M2)
where M1: Message + Send + 'static, M2: Message + Send + 'static,

Source

impl<M1> Message for (M1,)
where M1: Message + Send + 'static,

Source

impl<M> Message for Arc<M>
where M: Send + 'static + Sync,

Source

impl<M> Message for Box<M>
where M: Send + 'static,

Source

impl<M> Message for Box<[M]>
where M: Send + 'static,

Source

impl<M> Message for Vec<M>
where M: Send + 'static,

Implementors