PolyBox

Trait PolyBox 

pub trait PolyBox: DynPolyBox + Clone {
    type Set: Members;

    // Required method
    fn into_dyn_unchecked<T>(self) -> DynInbox<T>;
}
A trait that allows for conversions to DynInbox.

Required Associated Types

type Set: Members

The set of message types that this inbox can accept.

Required Methods

fn into_dyn_unchecked<T>(self) -> DynInbox<T>

Converts into a dynamic inbox without checking if the types are compatible.

Avoid using this method unless you are sure that the types are compatible, as it can lead to runtime errors. Instead, consider using into_dyn_checked or into_dyn_subset for safer conversions.

Safety

This method is not marked as unsafe, because violating the type system can only lead to runtime errors, not undefined behavior.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors