#[derive(Message)]
{
// Attributes available to this derive:
#[polybox]
#[msg]
}
Derives the Message trait for a struct, allowing it to be used as a message
in the Polybox framework.
This macro accepts an optional reply attribute to specify the reply type for the message.
Example
ⓘ
#[derive(Message)]
struct SimpleMessage;
#[derive(Message)]
#[msg(reply = u32)]
struct MessageWithReply;