pub trait Message:
Send
+ 'static
+ Sized {
type Kind: MessageSpecifier<Self>;
}Expand description
A trait that must be implemented for all types that are sent as messages.
It defines the kind of the message, which can be either Request<T> or FireAndForget.
Required Associated Types
Sourcetype Kind: MessageSpecifier<Self>
type Kind: MessageSpecifier<Self>
The kind of the message, which can be either Request<T> or FireAndForget.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".